summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--admin/kde.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/admin/kde.py b/admin/kde.py
index 92e22a2..a736e3b 100644
--- a/admin/kde.py
+++ b/admin/kde.py
@@ -4,8 +4,8 @@
import os, re, types
from SCons.Script.SConscript import SConsEnvironment
# Returns the name of the shared object (i.e. libkdeui.so.4)
# referenced by a libtool archive (like libkdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()
match = re.search("^dlname='([^']*)'$", contents, re.M)
@@ -114,8 +114,8 @@ def detect_kde(env):
else:
try:
tmplibdir = os.popen(kde_config+' --expandvars --install lib').read().strip()
- libkdeuiSO = env.join(tmplibdir, getSOfromLA(env.join(tmplibdir,'/libkdeui.la')) )
- m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libtqt').read().strip().split()[2])
+ libtdeuiSO = env.join(tmplibdir, getSOfromLA(env.join(tmplibdir,'/libtdeui.la')) )
+ m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libtqt').read().strip().split()[2])
except: m=None
if m:
qtdir = m.group(1)
@@ -4,8 +4,8 @@
import os, re, types
from SCons.Script.SConscript import SConsEnvironment
-# Returns the name of the shared object (i.e. libkdeui.so.4)
-# referenced by a libtool archive (like libkdeui.la)
+# Returns the name of the shared object (i.e. libtdeui.so.4)
+# referenced by a libtool archive (like libtdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()